'use strict'

const mysql = require('mysql2/promise')

/**
 * hold each mysql connection
 */
class MyConnection {
  constructor(connect) {
    /**
     * raw mysql connection
     * @required
     */
    this.connect = connect
  }

  /**
   * wrapper around `query`
   *
   * @param sql {string}
   * @param params {array|object}
   * @returns {Promise.<Array>}
   */
  query(sql, params) {
    const c = this.connect
    return c.query.apply(c, arguments).then(data => data[0])  // return rows
  }

  /**
   * close connection
   *
   * @required
   * @returns {Promise.<*>}
   */
  close() {
    const c = this.connect
    this.connect = null

    return c.end()
  }
}

function connector(opts) {
  return {
    /**
     * open each connection
     *
     * @required
     */
    open() {
      return mysql.createConnection(opts)
        .then(connect => new MyConnection(connect))
    }
  }
}

exports = module.exports = connector
exports.MyConnection = MyConnection
